==> v1.6.tar.gz: qqsp/Qqsp.ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="68"/>
        <source>ToolBar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="319"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="533"/>
        <source>&amp;Quest</source>
        <translation>&amp;Квест</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="536"/>
        <source>Open game...</source>
        <translation>Открыть игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="541"/>
        <source>Restart game</source>
        <translation>Перезагрузить игру</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="549"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="555"/>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="558"/>
        <source>Open saved game...</source>
        <translation>Открыть сохраненную игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="562"/>
        <source>Save game...</source>
        <translation>Сохранить игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="566"/>
        <source>Quick Load</source>
        <translation>Быстрая загрузка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="570"/>
        <source>Quick Save</source>
        <translation>Быстрое сохранение</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="576"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="579"/>
        <source>Show / Hide</source>
        <translation>Показать / Скрыть</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="614"/>
        <source>Captions</source>
        <translation>Заголовки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="640"/>
        <source>Hotkeys for actions</source>
        <translation>Горячие клавиши для действий</translation>
    </message>
    <message>
        <source>Sound volume...</source>
        <translation type="vanished">Громкость...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="647"/>
        <source>Window / Fullscreen mode</source>
        <translation>Оконный / Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="655"/>
        <source>Display HTML code as plain text</source>
        <translation>Отображать исходный код HTML</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="666"/>
        <source>Options...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="672"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="675"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="708"/>
        <source>Main desc</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="714"/>
        <source>Objects</source>
        <translation>Предметы</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="726"/>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="739"/>
        <source>Additional desc</source>
        <translation>Дополнительное описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="770"/>
        <source>Input area</source>
        <translation>Поле ввода</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="781"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="990"/>
        <location filename="mainwindow.cpp" line="992"/>
        <location filename="mainwindow.cpp" line="1000"/>
        <source>Select game file</source>
        <translation>Выберите файл игры</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="990"/>
        <location filename="mainwindow.cpp" line="992"/>
        <location filename="mainwindow.cpp" line="1000"/>
        <source>QSP games (*.qsp *.gam)</source>
        <translation>Файлы игры QSP (*.qsp *.gam)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="279"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="334"/>
        <source>Input data</source>
        <translation>Ввод данных</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="377"/>
        <location filename="mainwindow.cpp" line="1034"/>
        <location filename="mainwindow.cpp" line="1036"/>
        <source>Select saved game file</source>
        <translation>Выберите файл сохраненной игры</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="377"/>
        <location filename="callbacks_gui.cpp" line="395"/>
        <location filename="mainwindow.cpp" line="1034"/>
        <location filename="mainwindow.cpp" line="1036"/>
        <location filename="mainwindow.cpp" line="1053"/>
        <location filename="mainwindow.cpp" line="1055"/>
        <source>Saved game files (*.sav)</source>
        <translation>Файлы сохранений (*.sav)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="395"/>
        <location filename="mainwindow.cpp" line="1053"/>
        <location filename="mainwindow.cpp" line="1055"/>
        <source>Select file to save</source>
        <translation>Выберите файл для сохранения</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1113"/>
        <source>, </source>
        <translation>, </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1114"/>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017, S.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Авторские права &amp;copy; 2017, S.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1116"/>
        <source>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Qt library version: %3&lt;br&gt;Application compilation date: %4&lt;br&gt;Library compilation date: %5&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Application compilation date: %3&lt;br&gt;Library compilation date: %4&lt;/p&gt;</oldsource>
        <translation>&lt;p&gt;Версия приложения: %1&lt;br&gt;Версия библиотеки QSP: %2&lt;br&gt;Версия библиотеки Qt: %3&lt;br&gt;Дата компиляции приложения: %4&lt;br&gt;Дата компиляции библиотеки: %5&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1117"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.ui" line="17"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="28"/>
        <source>Use custom font size</source>
        <translation>Использовать выбранный размер шрифта</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="42"/>
        <source>Use custom font</source>
        <translation>Использовать выбранный шрифт</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="71"/>
        <location filename="optionsdialog.ui" line="127"/>
        <location filename="optionsdialog.ui" line="207"/>
        <location filename="optionsdialog.ui" line="256"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="80"/>
        <source>Custom background color</source>
        <translation>Использовать выбранный цвет фона</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="136"/>
        <source>Language</source>
        <translation>Язык (Language)</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="146"/>
        <source>Custom text color</source>
        <translation>Использовать выбранный цвет текста</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="153"/>
        <source>Custom link color</source>
        <translation>Использовать выбранный цвет ссылок</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="160"/>
        <source>Autostart last game</source>
        <translation>Автозагрузка последней игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="265"/>
        <source>Separate config per game</source>
        <translation>Отдельные настройки для каждой игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="272"/>
        <source>Sound volume</source>
        <translation>Громкость звука</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="289"/>
        <source>Disable video</source>
        <translation>Отключить поддержку видео</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="296"/>
        <source>Force autoplay and loop for video</source>
        <translation>Добавлять autoplay и loop для &lt;video&gt;</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="333"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="340"/>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="24"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="main.cpp" line="25"/>
        <location filename="mainwindow.cpp" line="110"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
<context>
    <name>QspExecWebEngineUrlSchemeHandler</name>
    <message>
        <location filename="qspexecwebengineurlschemehandler.cpp" line="52"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>QspImgCanvas</name>
    <message>
        <location filename="qspimgcanvas.cpp" line="9"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
</context>
<context>
    <name>QspMsgDlg</name>
    <message>
        <location filename="qspmsgdlg.cpp" line="32"/>
        <source>OK</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>__LANG__</name>
    <message>
        <location filename="optionsdialog.cpp" line="49"/>
        <location filename="optionsdialog.cpp" line="58"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="49"/>
        <location filename="optionsdialog.cpp" line="58"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="38"/>
        <source>Game file to open.</source>
        <translation>Путь до файла игры.</translation>
    </message>
</context>
</TS>

==> v1.8.tar.gz: qqsp/Qqsp.ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="68"/>
        <source>ToolBar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="358"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="586"/>
        <source>&amp;Quest</source>
        <translation>&amp;Квест</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="589"/>
        <source>Open game...</source>
        <translation>Открыть игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="594"/>
        <source>Restart game</source>
        <translation>Перезагрузить игру</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="602"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="608"/>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="611"/>
        <source>Open saved game...</source>
        <translation>Открыть сохраненную игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="615"/>
        <source>Save game...</source>
        <translation>Сохранить игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="619"/>
        <source>Quick Load</source>
        <translation>Быстрая загрузка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="623"/>
        <source>Quick Save</source>
        <translation>Быстрое сохранение</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="629"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="632"/>
        <source>Show / Hide</source>
        <translation>Показать / Скрыть</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="667"/>
        <source>Captions</source>
        <translation>Заголовки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="693"/>
        <source>Hotkeys for actions</source>
        <translation>Горячие клавиши для действий</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1200"/>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017-2019, Sonnix&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Авторские права &amp;copy; 2017-2019, Sonnix&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017-2018, Sonnix&lt;/p&gt;</source>
        <translation type="vanished">&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Авторские права &amp;copy; 2017-2018, Sonnix&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Sound volume...</source>
        <translation type="vanished">Громкость...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="700"/>
        <source>Window / Fullscreen mode</source>
        <translation>Оконный / Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="708"/>
        <source>Display HTML code as plain text</source>
        <translation>Отображать исходный код HTML</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="719"/>
        <source>Options...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="725"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="728"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="755"/>
        <source>Main desc</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="761"/>
        <source>Objects</source>
        <translation>Предметы</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="773"/>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="786"/>
        <source>Additional desc</source>
        <translation>Дополнительное описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="811"/>
        <source>Input area</source>
        <translation>Поле ввода</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="822"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1068"/>
        <location filename="mainwindow.cpp" line="1070"/>
        <location filename="mainwindow.cpp" line="1078"/>
        <source>Select game file</source>
        <translation>Выберите файл игры</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1068"/>
        <location filename="mainwindow.cpp" line="1070"/>
        <location filename="mainwindow.cpp" line="1078"/>
        <source>QSP games (*.qsp *.gam)</source>
        <translation>Файлы игры QSP (*.qsp *.gam)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="296"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="351"/>
        <source>Input data</source>
        <translation>Ввод данных</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="394"/>
        <location filename="mainwindow.cpp" line="1112"/>
        <location filename="mainwindow.cpp" line="1114"/>
        <source>Select saved game file</source>
        <translation>Выберите файл сохраненной игры</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="394"/>
        <location filename="callbacks_gui.cpp" line="412"/>
        <location filename="mainwindow.cpp" line="1112"/>
        <location filename="mainwindow.cpp" line="1114"/>
        <location filename="mainwindow.cpp" line="1131"/>
        <location filename="mainwindow.cpp" line="1133"/>
        <source>Saved game files (*.sav)</source>
        <translation>Файлы сохранений (*.sav)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="412"/>
        <location filename="mainwindow.cpp" line="1131"/>
        <location filename="mainwindow.cpp" line="1133"/>
        <source>Select file to save</source>
        <translation>Выберите файл для сохранения</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1199"/>
        <source>, </source>
        <translation>, </translation>
    </message>
    <message>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017, S.&lt;/p&gt;</source>
        <translation type="vanished">&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Авторские права &amp;copy; 2017, S.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1202"/>
        <source>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Qt library version: %3&lt;br&gt;Application compilation date: %4&lt;br&gt;Library compilation date: %5&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Application compilation date: %3&lt;br&gt;Library compilation date: %4&lt;/p&gt;</oldsource>
        <translation>&lt;p&gt;Версия приложения: %1&lt;br&gt;Версия библиотеки QSP: %2&lt;br&gt;Версия библиотеки Qt: %3&lt;br&gt;Дата компиляции приложения: %4&lt;br&gt;Дата компиляции библиотеки: %5&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1203"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.ui" line="17"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="28"/>
        <source>Use custom font size</source>
        <translation>Использовать выбранный размер шрифта</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="42"/>
        <source>Use custom font</source>
        <translation>Использовать выбранный шрифт</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="71"/>
        <location filename="optionsdialog.ui" line="127"/>
        <location filename="optionsdialog.ui" line="207"/>
        <location filename="optionsdialog.ui" line="256"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="80"/>
        <source>Custom background color</source>
        <translation>Использовать выбранный цвет фона</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="136"/>
        <source>Language</source>
        <translation>Язык (Language)</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="146"/>
        <source>Custom text color</source>
        <translation>Использовать выбранный цвет текста</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="153"/>
        <source>Custom link color</source>
        <translation>Использовать выбранный цвет ссылок</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="160"/>
        <source>Autostart last game</source>
        <translation>Автозагрузка последней игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="265"/>
        <source>Separate config per game</source>
        <translation>Отдельные настройки для каждой игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="272"/>
        <source>Sound volume</source>
        <translation>Громкость звука</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="289"/>
        <source>Disable video</source>
        <translation>Отключить поддержку видео</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="296"/>
        <source>Force autoplay and loop for video</source>
        <translation>Добавлять autoplay и loop для &lt;video&gt;</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="303"/>
        <source>HTML5 Extras (experimental)</source>
        <translation>Экспериментальный функционал для HTML5</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="343"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="350"/>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="24"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="main.cpp" line="25"/>
        <location filename="mainwindow.cpp" line="113"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
<context>
    <name>QspExecWebEngineUrlSchemeHandler</name>
    <message>
        <location filename="qspexecwebengineurlschemehandler.cpp" line="52"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>QspImgCanvas</name>
    <message>
        <location filename="qspimgcanvas.cpp" line="9"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
</context>
<context>
    <name>QspMsgDlg</name>
    <message>
        <location filename="qspmsgdlg.cpp" line="32"/>
        <source>OK</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>QspWebChannel</name>
    <message>
        <location filename="qspwebchannel.cpp" line="38"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>__LANG__</name>
    <message>
        <location filename="optionsdialog.cpp" line="50"/>
        <location filename="optionsdialog.cpp" line="59"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="50"/>
        <location filename="optionsdialog.cpp" line="59"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="49"/>
        <source>Game file to open.</source>
        <translation>Путь до файла игры.</translation>
    </message>
</context>
</TS>
